# SEC05: How do you protect your network resources?

## References

- [AWS SEC05](https://docs.aws.amazon.com/wellarchitected/latest/framework/sec-05.html)

## Date

2025-11-27

## Focus Area

Infrastructure Protection

## Tổng quan

SEC05 tập trung vào bảo vệ network resources.

## Best Practices

| BP | Name | Description |
|----|------|-------------|
| [SEC05-BP01](SEC05-BP01-Network-Layers.md) | Network layers | Network segmentation |
| [SEC05-BP02](SEC05-BP02-Control-Traffic.md) | Control traffic | Security groups, NACLs, WAF |
| [SEC05-BP03](SEC05-BP03-Automate-Protection.md) | Automate protection | Automated rules |
| [SEC05-BP04](SEC05-BP04-Inspection-Protection.md) | Inspection and protection | Traffic inspection |

## Checklist

- [ ] Network segmented
- [ ] Security groups configured
- [ ] WAF deployed
- [ ] Traffic inspection enabled
